@@ -198,7 +198,19 @@ class EventsRuleToStepFunction(
         :summary: Constructs a new instance of the EventsRuleToStepFunction class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EventsRuleToStepFunction.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+                state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventsRuleToStepFunctionProps(
@@ -212,29 +224,29 @@ class EventsRuleToStepFunction(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="eventsRule")
     def events_rule(self) -> aws_cdk.aws_events.Rule:
         return typing.cast(aws_cdk.aws_events.Rule, jsii.get(self, "eventsRule"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="stateMachine")
     def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
         return typing.cast(aws_cdk.aws_stepfunctions.StateMachine, jsii.get(self, "stateMachine"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="stateMachineLogGroup")
     def state_machine_log_group(self) -> aws_cdk.aws_logs.ILogGroup:
         return typing.cast(aws_cdk.aws_logs.ILogGroup, jsii.get(self, "stateMachineLogGroup"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="eventBus")
     def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
         return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
@@ -282,7 +294,17 @@ class EventsRuleToStepFunctionProps:
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
-            type_hints = typing.get_type_hints(EventsRuleToStepFunctionProps.__init__)
+            def stub(
+                *,
+                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+                state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
             check_type(argname="argument state_machine_props", value=state_machine_props, expected_type=type_hints["state_machine_props"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
